@@ -110,7 +110,6 @@ class KinMS:
             else:
                 self.seed = np.array([100, 101, 102, 103], dtype='int')
             
-
         self.cleanOut = cleanOut
         self.huge_beam = huge_beam
         self.verbose = verbose        
@@ -797,7 +796,7 @@ class KinMS:
                 if not (len(self.flux_clouds.shape) == 1 and len(self.flux_clouds) == max(self.inClouds.shape)):
                     raise KinMSError('\nPlease make sure \"flux_clouds\" is a 1D array matching the length of \"inClouds\".')
 
-                #cube = np.zeros((np.int(x_size), np.int(y_size), np.int(v_size)))
+                #cube = np.zeros((int(x_size), int(y_size), int(v_size)))
                 
                 cube, edges = np.histogramdd(clouds2do, bins=(self.x_size, self.y_size, self.v_size),
                                                  range=((0, self.x_size), (0, self.y_size), (0, self.v_size)),weights=self.flux_clouds[subs])                                 
@@ -807,7 +806,7 @@ class KinMS:
                 #cube, edges =np.histogramdd(clouds2do, bins=(x_size, y_size, v_size),range=((0, x_size), (0, y_size), (0, v_size)))
 
         else:
-            cube = np.zeros((np.int(self.x_size), np.int(self.y_size), np.int(self.v_size)))
+            cube = np.zeros((int(self.x_size), int(self.y_size), int(self.v_size)))
 
         return cube
         
